#define HELP_INTRO _(\
"Help commands:\n" \
"  help [<command>]\n" \
"  copying\n" \
"  warranty\n" \
"\n" \
"Schema commands:\n" \
"  catalogs\n" \
"  schemas\n" \
"  tables [<catalog>]\n" \
"  columns <table>\n" \
"\n" \
"Transaction commands:\n" \
"  autocommit on|off\n" \
"  commit\n" \
"  rollback\n" \
"\n" \
"Other commands:\n" \
"  set [<variable>] [<value>]\n" \
"  unset <variable>\n" \
"  info" \
		)

#define HELP_NOTFOUND _("Help topic doesn't exist")

